<template>
  <div class="rightContent">
    <div class="content-box">
      <div class="supplier-search">
        <SearchCommonView
          ref="searchCommonView"
          :inputSelect="false"
          placeholder="可输入采购单,供应商名称等搜索"
          @searchClick="searchClick"
          @resetClick="resetClick"
        />
        
      </div>
      <template>
        <TableCommonView
         class="content-table"
          ref="tableListRef"
          :table-list="tableList"
          @selCommonClick="selCommonClick"
        >
          <template slot="tableButton">
            <el-table-column label="状态" width="120">
              <template slot-scope="scope">
               {{ getReturnedStatus(scope.row.member_name) }}
              </template>
            </el-table-column>
            <el-table-column label="操作" width="120">
              <template slot-scope="scope">
                <el-button  @click="confirmClick(scope.row)" type="text" size="small">确认发货</el-button>
              </template>
            </el-table-column>
          </template>
        </TableCommonView>
        <div class="btn-pager">
          <PagerView class="page" :pager-options="pagerOptions" v-on="pagerEvents" />
        </div>
      </template>
    </div>
  
    <!-- 新建/编辑销售线索 -->
    <!-- <AddSalesLeadDialog v-if="editSalesLeadConfig.visible" :edit-rightContent-config="editSalesLeadConfig" /> -->
    <!-- 详情 -->
    <DetailSupplier v-if="commonDetail.visible" :common-detail="commonDetail" />
  </div>
</template>

<script>
import pageMixin from "@/components/makepager/pager/mixin/pageMixin"
import {
  getPurchaseList,getPurchaseInfo,submitPurchase, 
} from "@/api/purchaseManage/purchase";
import DetailSupplier from "@/views/purchaseManage/returned/DetailSupplier"
import { getDataByType } from "@/api/data";
export default {
  name: "SupplierManage",
  props: {},
  components: { DetailSupplier },
  mixins: [pageMixin],
  computed: {},
  data() {
    return {
      tableList: {}, // 列表
      selValueList: [],
      commonDetail: {
        visible: false,
        infomation: {}
      },
      search: '',
      returnedStatusList:getDataByType('returnedStatus'),
    }
  },
  created() {
    this.setTable()
    this.getData()
  },
  methods: {
    getReturnedStatus(val) {
      if (val) {
        for (let i in this.returnedStatusList) {
          if (this.returnedStatusList[i].id == val) {
            return this.returnedStatusList[i].name;
          }
        }
      } else {
        return "--";
      }
    },
    setTable() {
      this.tableList = {
        tableInfomation: [],
        selectIndex: true,
        tableColumn: [
          { label: "退货单编号", prop: "number", min: 190, isCommonClick: true },
          { label: "采购单编号", prop: "name", min: 130, isCommonClick: true},
          { label: "单据类型", prop: "contact_name", min: 130 },
          { label: "供应商名称", prop: "contact_phone", min: 130 },
          { label: "退货仓库", prop: "sales_resources", min: 130 },
          { label: "退货理由", prop: "province", min: 180 },
          { label: "经办人", prop: "city", min: 130 },
          { label: "制单人", prop: "member_name", min: 130 },
          { label: "退货日期", prop: "member_name", min: 150 },
          // { label: "状态", prop: "member_name", min: 110 }
        ]
      }
    },
    // 请求数据
    async getData() {
      await getPurchaseList({
        keyword: this.search,
        page: this.pagerOptions.currPage,
        pageSize: this.pagerOptions.pageSize
      })
        .then((res) => {
          const list = res.data.data.list
          this.tableList.tableInfomation = list || []
          this.pagerOptions.totalCount = res.data.total
        })
        .catch((err) => {
          console.log(err)
        })
    },
    // 搜索
    searchClick(val, content) {
      console.log(val, content)
      this.search =  content
  
      this.getData()
    },
    resetClick() {
      this.search = ''
      this.getData()
    },
   
    // 确认发货
    confirmClick() {
        this.$confirm("是否确认发货?", "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        })
          .then(() => {
            console.log("dddd")
            submitPurchase({ ids: this.selValueList }).then((response) => {
              if (response.code === 200) {
                this.$message.success("确认发货成功")
                this.getData()
              } else {
                this.$message.warning("确认发货失败")
              }
            })
          })
          .catch(() => {})
    },
    
    // 详情
    selCommonClick(row) {
      console.log(row)
      getPurchaseInfo({id:row.ID}).then((res) => {
        if (res.code == 200) {
          this.commonDetail.visible = true
          this.commonDetail.infomation = { 
            productList:res.data.productList,
            ...res.data.purchase
           }
        }else{
          this.$message.error(res.msg?res.msg+',':''+'获取信息失败！')
        }
      })
    }
  }
}
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped>
.rightContent {
  width:100%;
  height:calc(100% - 10px);
  .content-box {
    height:100%;
    .supplier-search {
      display: flex;
      align-items: center;
      .add-view {
        margin-left: auto;
        margin-right: 20px;
      }
    }
    .content-table{
      // height:calc(100% - 60px - 42px);
    }
    .btn-pager {
      display: flex;
      .page {
        margin-left: auto;
      }
    }
  }
  .bottom {
    .product-search {
      display: flex;
      align-items: center;
      .search {
        margin-left: auto;
      }
      .add-view {
        margin-left: 20px;
        margin-right: 20px;
      }
    }
    .btn-pager {
      display: flex;
      .page {
        margin-left: auto;
      }
    }
  }
}
</style>
